@@ -1,5 +1,5 @@
 package POEx::IRC::Backend;
-$POEx::IRC::Backend::VERSION = '0.027005';
+$POEx::IRC::Backend::VERSION = '0.027006';
 use strictures 2;
 
 use Carp;
@@ -244,10 +244,12 @@ sub _accept_conn {
   }
   my $listener = $self->listeners->{$listener_id};
 
+  my $really_ssl;
   if ( $listener->ssl ) {
     try {
       die "Failed to load POE::Component::SSLify" unless $self->has_ssl_support;
-      $sock = POE::Component::SSLify::Client_SSLify($sock)
+      $sock = POE::Component::SSLify::Server_SSLify($sock);
+      $really_ssl = 1
     } catch {
       warn "Could not SSLify (server) socket: $_\n";
       undef
@@ -267,7 +269,11 @@ sub _accept_conn {
     return
   }
 
-  my ($sockaddr, $sockport) = get_unpacked_addr( getsockname $sock );
+  my ($sockaddr, $sockport) = get_unpacked_addr( 
+    getsockname(
+      $really_ssl ? POE::Component::SSLify::SSLify_GetSocket($sock) : $sock
+    )
+  );
   my $this_conn = POEx::IRC::Backend::Connect->new(
     protocol  => $protocol,
     wheel     => $wheel,
@@ -511,10 +517,12 @@ sub _connector_up {
   ## No need to try to connect out any more; remove from connectors pool:
   my $ct = delete $self->connectors->{$c_id};
 
+  my $really_ssl;
   if ( $ct->ssl ) {
     try {
       die "Failed to load POE::Component::SSLify" unless $self->has_ssl_support;
-      $sock = POE::Component::SSLify::Client_SSLify($sock)
+      $sock = POE::Component::SSLify::Client_SSLify($sock);
+      $really_ssl = 1
     } catch {
       warn "Could not SSLify (client) socket: $_\n";
       undef
@@ -536,7 +544,11 @@ sub _connector_up {
     return
   }
 
-  my ($sockaddr, $sockport) = get_unpacked_addr( getsockname $sock );
+  my ($sockaddr, $sockport) = get_unpacked_addr(
+    getsockname(
+      $really_ssl ? POE::Component::SSLify::SSLify_GetSocket($sock) : $sock
+    )
+  );
 
   my $this_conn = POEx::IRC::Backend::Connect->new(
     ($ct->has_args ? (args => $ct->args) : () ),
@@ -981,6 +993,12 @@ L<POEx::IRC::Backend::Connect> still has an active wheel attached:
     $backend->disconnect( $this_conn )
   }
 
+Note that disconnection happens after a buffer flush; if your software does
+not perform entirely like a traditional platform (server implementations
+will typically send C<< ERROR: Closing Link >> or similar to clients marked
+for disconnection, which will trigger a buffer flush) you may currently experience
+"late" disconnects. This behavior may be subject to change in future versions.
+
 =head3 send
 
   $backend->send(
@@ -1192,6 +1210,9 @@ Zlib and SSL are mostly untested.
 L<POEx::IRC::Client::Lite> for an experimental IRC client library using this
 backend.
 
+L<https://github.com/miniCruzer/irssi-bouncer> for an irssi-based
+bouncer/proxy system using this backend.
+
 L<POE::Filter::IRCv3> and L<IRC::Message::Object> for documentation regarding
 IRC message parsing.
 
